@@ -55,7 +55,7 @@ public:
     void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override;
     QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 
-public slots:
+public Q_SLOTS:
     void reset();
 
 private:
