@@ -114,7 +114,7 @@ SearchFileListView::SearchFileListView(QWidget* parent)
 
 void SearchFileListView::requestFileOpen(const QModelIndex& item)
 {
-    emit fileOpenRequested(item.data(Qt::UserRole).toString(), true);
+    Q_EMIT fileOpenRequested(item.data(Qt::UserRole).toString(), true);
 }
 
 void SearchFileListView::addFiles(const QStringList& files)
@@ -128,9 +128,10 @@ void SearchFileListView::addFiles(const QStringList& files)
 
     //ensure unquiness, sorting the list along the way
     QMap<QString, bool> map;
-    foreach (const QString& filepath, m_model->stringList())
+    const auto filepaths = m_model->stringList();
+    for (const QString& filepath : filepaths)
         map[filepath] = true;
-    foreach (const QString& filepath, files)
+    for (const QString& filepath : files)
         map[filepath] = true;
 
     m_model->setStringList(map.keys());
@@ -204,7 +205,7 @@ void SearchJob::run()
                                && !searchParams.sourcePattern.pattern().contains(QLatin1Char('&'));
     bool removeAmpFromTarget = searchParams.targetPattern.patternSyntax() == QRegExp::FixedString
                                && !searchParams.targetPattern.pattern().contains(QLatin1Char('&'));
-    foreach (const QString& filePath, files) {
+    for (const QString& filePath : qAsConst(files)) {
         Catalog catalog(nullptr);
         if (Q_UNLIKELY(catalog.loadFromUrl(filePath, QString(), &m_size, true) != 0))
             continue;
@@ -262,7 +263,7 @@ void SearchJob::run()
         //    results[path]=catalogResults;
     }
     qCDebug(LOKALIZE_LOG) << "searching took" << a.elapsed();
-    emit done(this);
+    Q_EMIT done(this);
 }
 
 MassReplaceJob::MassReplaceJob(const SearchResults& srs, int pos, const QRegExp& s, const QString& r, QObject*)
@@ -281,12 +282,14 @@ void MassReplaceJob::run()
     for (int i = 0; i < searchResults.count(); ++i)
         map.insertMulti(searchResults.at(i).filepath, i);
 
-    foreach (const QString& filepath, map.keys()) {
+    const auto filepaths = map.keys();
+    for (const QString& filepath : filepaths) {
         Catalog catalog(QThread::currentThread());
         if (catalog.loadFromUrl(filepath, QString()) != 0)
             continue;
 
-        foreach (int index, map.values(filepath)) {
+        const auto indexes = map.values(filepath);
+        for (int index : indexes) {
             SearchResult& sr = searchResults[index];
             DocPosition docPos = sr.docPos.toDocPosition();
             if (catalog.target(docPos) != sr.target) {
@@ -419,7 +422,7 @@ void FileSearchModel::setReplacePreview(const QRegExp& s, const QString& r)
     m_replaceWhat = s;
     m_replaceWith = QLatin1String("_ST_") + r + QLatin1String("_END_");
 
-    emit dataChanged(index(0, Target), index(rowCount() - 1, Target));
+    Q_EMIT dataChanged(index(0, Target), index(rowCount() - 1, Target));
 }
 
 
@@ -664,7 +667,7 @@ void FileSearchTab::openFile()
         selection    = sr.targetPositions.first().len;
     }
     qCDebug(LOKALIZE_LOG) << "fileOpenRequest" << docPos.offset << selection;
-    emit fileOpenRequested(sr.filepath, docPos, selection, true);
+    Q_EMIT fileOpenRequested(sr.filepath, docPos, selection, true);
 }
 
 void FileSearchTab::fileSearchNext()
@@ -847,7 +850,7 @@ void MassReplaceView::requestPreviewUpdate()
     if (s.length())
         ui->doReplace->setEnabled(true);
 
-    emit previewRequested(regExpFromUi(s, ui), r);
+    Q_EMIT previewRequested(regExpFromUi(s, ui), r);
 }
 
 
@@ -866,7 +869,7 @@ void MassReplaceView::requestPreview(bool enable)
         disconnect(ui->useRegExps, &QCheckBox::toggled, this, &MassReplaceView::requestPreviewUpdate);
         disconnect(ui->matchCase, &QCheckBox::toggled, this, &MassReplaceView::requestPreviewUpdate);
 
-        emit previewRequested(QRegExp(), QString());
+        Q_EMIT previewRequested(QRegExp(), QString());
     }
 }
 
@@ -878,7 +881,7 @@ void MassReplaceView::requestReplace()
     if (s.isEmpty())
         return;
 
-    emit replaceRequested(regExpFromUi(s, ui), r);
+    Q_EMIT replaceRequested(regExpFromUi(s, ui), r);
 }
 
 void MassReplaceView::deactivatePreview()
