@@ -389,7 +389,7 @@ void ProjectWidget::slotItemActivated(const QModelIndex& index)
         QModelIndex srcIndex = static_cast<QSortFilterProxyModel*>(m_proxyModel)->mapToSource(index);
         QUrl fileUrl = srcModel->beginEditing(srcIndex);
 
-        emit fileOpenRequested(fileUrl.toLocalFile(), !(QApplication::keyboardModifiers() & Qt::ControlModifier));
+        Q_EMIT fileOpenRequested(fileUrl.toLocalFile(), !(QApplication::keyboardModifiers() & Qt::ControlModifier));
     }
 }
 
@@ -417,7 +417,8 @@ void ProjectWidget::recursiveAdd(QStringList& list, const QModelIndex& idx) cons
 QStringList ProjectWidget::selectedItems() const
 {
     QStringList list;
-    foreach (const QModelIndex& item, selectedIndexes()) {
+    const auto items = selectedIndexes();
+    for (const QModelIndex& item : items) {
         if (item.column() == 0)
             recursiveAdd(list, m_proxyModel->mapToSource(item));
     }
