@@ -229,7 +229,7 @@ bool QaModel::setData(const QModelIndex& item, const QVariant& value, int role)
     for (int i = 0; i < sources.size(); i++)
         setText(sources.at(i).toElement(), newSources.at(i));
 
-    emit dataChanged(item, item);
+    Q_EMIT dataChanged(item, item);
     return true;
 }
 
